/*
 *  kalarm.h  -  global header file; provides KDE & Qt version compatibility
 *  Program:  kalarm
 *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KALARM_H
#define KALARM_H

#define KALARM_VERSION VERSION
#define KALARM_NAME "KAlarm"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kdeversion.h>
#define KDE_VERSION_PRE_3_1        (KDE_VERSION < 306)         // KDE <= 3.0.x
#define KDE_VERSION_PRE_3_2        (!KDE_IS_VERSION(3,1,90))   // KDE <= 3.1.x
#define KDE_VERSION_PRE_3_2_BETA1  (!KDE_IS_VERSION(3,1,93))   // KDE < 3.2.0 Beta 1
#define KDE_VERSION_PRE_3_3        (!KDE_IS_VERSION(3,2,90))   // KDE <= 3.2.x

#if KDE_VERSION_PRE_3_1
	// Add a missing KURL method
	#include <kurl_30.h>
	// Counteract ksystemtray_31.h
	#include <kkeydialog_30.h>
	// Remove a missing KMainWindow method
	#define setStandardToolBarMenuEnabled(x)
#endif

#if KDE_VERSION_PRE_3_2_BETA1
	// Compatibility for pre-KDE 3.2 Beta 1

	// Redefine KWinModule class
	#include <kwinmodule_31.h>
#endif

#if KDE_VERSION_PRE_3_2
	// Compatibility for pre-KDE 3.2

	// Redefine KWin class
	#include <kwin_31.h>
	// Redefine KGlobal class
	#include <kglobal_31.h>
	// Redefine KLocale class
	#include <klocale_31.h>    // must be included before ksystemtray_31.h
	// Redefine KGlobalSettings class
	#include <kglobalsettings_31.h>
	// Redefine KMessageBox class
	#include <kmessagebox_31.h>
	// Redefine KSaveFile class
	#include <ksavefile_31.h>
	// Redefine KStdGuiItem class
	#include <kstdguiitem_31.h>
	// Redefine KSystemTray class
	#include <ksystemtray_31.h>
	// Redefine KShell namespace
	#include <kshell_31.h>
	// Redefine KIO::NetAccess class
	#include <netaccess_31.h>
#endif

#if KDE_VERSION_PRE_3_3
	// Compatibility for pre-KDE 3.3

	// Redefine KToggleAction class
	#include <kaction_32.h>
#endif

#include <qglobal.h>
#define QT_VERSION_PRE_3_1  (QT_VERSION < 0x030100)    // Qt <= 3.0.x

#if QT_VERSION_PRE_3_1
	// Compatibility for pre-Qt 3.1

	// Define QDateTime::toTime_t()
	#include <qdatetime_30.h>
#endif

#if KDE_IS_VERSION(3,4,0)
#define AUTOSTART_BY_KALARMD    // temporary fix for autostart before session restoration
#endif

#if KDE_IS_VERSION(3,2,0)
#define LIKEBACK
#endif

#define OLD_DCOP    // retain DCOP pre-1.2 compatibility

#endif // KALARM_H

